@@ -7,7 +7,7 @@ use cursive::event::{AnyCb, Event, EventResult};
 use cursive::theme::{ColorStyle, ColorType, Theme};
 use cursive::traits::View;
 use cursive::vec::Vec2;
-use cursive::view::{IntoBoxedView, Selector};
+use cursive::view::{CannotFocus, IntoBoxedView, Selector};
 use cursive::views::EditView;
 use cursive::{Cursive, Printer};
 use log::debug;
@@ -311,6 +311,7 @@ impl View for Layout {
         }
 
         if self.cmdline_focus {
+            debug!("cmdline event");
             return self.cmdline.on_event(event);
         }
 
@@ -327,7 +328,7 @@ impl View for Layout {
         }
     }
 
-    fn take_focus(&mut self, source: Direction) -> bool {
+    fn take_focus(&mut self, source: Direction) -> Result<EventResult, CannotFocus> {
         if self.cmdline_focus {
             return self.cmdline.take_focus(source);
         }
@@ -335,7 +336,7 @@ impl View for Layout {
         if let Some(view) = self.get_current_view_mut() {
             view.take_focus(source)
         } else {
-            false
+            Err(CannotFocus)
         }
     }
 }
