@@ -85,7 +85,6 @@ impl<I: ListItem> ListView<I> {
 
     pub fn content_height_with_paginator(&self) -> usize {
         let content_len = self.content.read().unwrap().len();
-        log::info!("content len: {content_len}");
 
         // add 1 more row for paginator if we can paginate
         if self.can_paginate() {
@@ -96,8 +95,6 @@ impl<I: ListItem> ListView<I> {
     }
 
     fn can_paginate(&self) -> bool {
-        let loaded = self.get_pagination().loaded_content();
-        log::info!("can paginate: {loaded}");
         self.get_pagination().max_content().unwrap_or(0) > self.get_pagination().loaded_content()
     }
 
@@ -139,7 +136,7 @@ impl<I: ListItem> ListView<I> {
                 .map(|t| Playable::Track(t.clone()))
                 .collect::<Vec<Playable>>()
         });
-        if let Some(tracks) = playables.or_else(|| tracks.as_ref()) {
+        if let Some(tracks) = playables.or(tracks.as_ref()) {
             let index = self.queue.append_next(tracks);
             self.queue.play(index + self.selected, true, false);
             true
@@ -488,7 +485,7 @@ impl<I: ListItem + Clone> ViewExt for ListView<I> {
                         }
                         return Ok(CommandResult::Consumed(None));
                     }
-                    _ => {}
+                    _ => return Ok(CommandResult::Consumed(None)),
                 }
             }
             Command::Open(mode) => {
